==> scichains-cv-4.2.2-sources.jar: net/algart/executors/modules/opencv/matrices/objects/components/ConnectedComponents.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2023 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.matrices.objects.components;

import net.algart.executors.modules.opencv.common.VoidResultUMatFilter;
import net.algart.executors.modules.util.opencv.enums.OConnectivity;
import org.bytedeco.opencv.global.opencv_core;
import org.bytedeco.opencv.opencv_core.*;
import org.bytedeco.opencv.global.opencv_imgproc;

public final class ConnectedComponents extends VoidResultUMatFilter {
    private OConnectivity connectivity = OConnectivity.CONNECTIVITY_8;

    public OConnectivity getConnectivity() {
        return connectivity;
    }

    public void setConnectivity(OConnectivity connectivity) {
        this.connectivity = nonNull(connectivity);
    }

    @Override
    public void process(Mat result, Mat source) {
        opencv_imgproc.connectedComponents(source, result, connectivity.code(), opencv_core.CV_32S);
    }

    @Override
    public void process(UMat result, UMat source) {
        opencv_imgproc.connectedComponents(source, result, connectivity.code(), opencv_core.CV_32S);
    }

    @Override
    protected boolean allowInputPackedBits() {
        return true;
    }
}

==> scichains-cv-4.3.1-sources.jar: net/algart/executors/modules/opencv/matrices/objects/components/ConnectedComponents.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2023 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.matrices.objects.components;

import net.algart.executors.modules.opencv.common.VoidResultUMatFilter;
import net.algart.executors.modules.opencv.util.enums.OConnectivity;
import org.bytedeco.opencv.global.opencv_core;
import org.bytedeco.opencv.opencv_core.*;
import org.bytedeco.opencv.global.opencv_imgproc;

public final class ConnectedComponents extends VoidResultUMatFilter {
    private OConnectivity connectivity = OConnectivity.CONNECTIVITY_8;

    public OConnectivity getConnectivity() {
        return connectivity;
    }

    public void setConnectivity(OConnectivity connectivity) {
        this.connectivity = nonNull(connectivity);
    }

    @Override
    public void process(Mat result, Mat source) {
        opencv_imgproc.connectedComponents(source, result, connectivity.code(), opencv_core.CV_32S);
    }

    @Override
    public void process(UMat result, UMat source) {
        opencv_imgproc.connectedComponents(source, result, connectivity.code(), opencv_core.CV_32S);
    }

    @Override
    protected boolean allowInputPackedBits() {
        return true;
    }
}
